@@ -6,12 +6,12 @@
 # under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # txt2boil is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with txt2boil.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -19,8 +19,8 @@
 
 """
 
-from extractor import Extractor
-from gen import Gen
-from hookedre import HookedRegex
+from .extractor import Extractor
+from .gen import Gen
+from .hookedre import HookedRegex
 
 __all__ = ['Extractor', 'Gen', 'HookedRegex']
